@@ -13,7 +13,7 @@ from ..db import init_db_pool
 from .alarms import AlarmsView, AlarmView
 from .listeners import ListenersView, ListenerView
 from .proximity import ProximityView, proximity_task
-from .tags import TagsView, TagView
+from .tags import TagsView, TagView, TagHistoryView
 from .zones import ZonesView, ZoneView
 from .groups import GroupsView, GroupView
 from ..demo_fe.main import app as demo_fe_app
@@ -45,6 +45,7 @@ def main(port, demo_fe) -> None:
     app.router.add_view('/api/zones/{id:\d+}', ZoneView, name='zone')
     app.router.add_view('/api/tags', TagsView)
     app.router.add_view('/api/tags/{id:\d+}', TagView, name='tag')
+    app.router.add_view('/api/tags/{id:\d+}/history', TagHistoryView, name='history')
     app.router.add_view('/api/proximity', ProximityView)
     app.router.add_view('/api/groups', GroupsView)
     app.router.add_view('/api/groups/{id:\d+}', GroupView, name='group')
