@@ -61,8 +61,10 @@ class TagCreateBase(Schema, AttrsMixin):
     zone_id = fields.Int(allow_none=True)
     group_id = fields.Int(allow_none=True)
     last_seen = fields.DateTime(dump_only=True)
-    type = fields.Str(required=True, validate=lambda x: x in {'iBeacon', 'SmartRelay', 'LocationAnchor'})
+    type = fields.Str(required=True, validate=lambda x: x in {
+        'iBeacon', 'SmartRelay', 'LocationAnchor', 'SecureLocationAnchor', 'SecureSmartRelay'})
     battery_pct = fields.Int(allow_none=True)
+    alarm_active = fields.Boolean(allow_none=True)
 
 
 class iBeaconTagMixin:
@@ -71,10 +73,18 @@ class iBeaconTagMixin:
     minor = fields.Int(required=True, validate=lambda x: x >= 0 < (2 ** 16))
 
 
+class SecureBeaconTagMixin:
+    bid = fields.Int(required=True)
+
+
 class MacBeaconTagMixin(RequiredMacMixin):
     pass
 
 
+class SecureBeaconCreateSchema(TagCreateBase, SecureBeaconTagMixin):
+    pass
+
+
 class iBeaconCreateSchema(TagCreateBase, iBeaconTagMixin):
     pass
 
@@ -95,6 +105,7 @@ class ProxSchema(Schema):
     zone_name = fields.Str(required=True)
     last_seen = fields.DateTime(required=True)
     tag_type = fields.Str(required=True)
+    alarm_active = fields.Str(required=True)
     links = fields.Nested(ProxLinks)
 
 
@@ -118,6 +129,13 @@ class AlarmPatch(Schema):
     acknowledged = fields.Boolean(required=True)
 
 
+class HistorySchema(Schema):
+    ts = fields.DateTime(required=True)
+    zone_id = fields.Int(required=True)
+    zone_name = fields.Str(required=True)
+    distance_cm = fields.Float(required=True)
+
+
 listeners_schema = ListenerSchema(many=True)
 listener_schema = ListenerSchema()
 
@@ -128,6 +146,7 @@ group_schema = GroupSchema()
 
 ibeacon_post_schema = iBeaconCreateSchema()
 macbeacon_post_schema = MacBeaconCreateSchema()
+secure_beacon_post_schema = SecureBeaconCreateSchema()
 tag_patch_schema = TagPatchSchema()
 
 prox_schema = ProxSchema(many=True)
@@ -135,3 +154,5 @@ prox_schema = ProxSchema(many=True)
 alarm_schema = AlarmSchema()
 alarms_schema = AlarmSchema(many=True)
 alarm_patch_schema = AlarmPatch()
+
+history_schema = HistorySchema(many=True)
